<control-tabs>

	<div class="control-tabs" id="{ state.control_id }" if="{ Device == 'lg' || Device == 'md' }">
		<div class="custom-tabs visible-tabs">
	    	<a href="#" each="{ tab in state.visible_tabs }" class="tab { state.tab && state.tab.id == tab.id ? 'active' : '' }" onclick="{ tab_click }">{ tab.title }</a>
		</div>

		<div class="dropdown" show="{ state.show_dropdown }">
			<a href="#" class="tab { state.dropdown_tab ? 'active' : '' } dropdown-toggle " id="dropdown{ state.control_id }" data-toggle="dropdown" aria-haspopup="true" aria-expanded="true">
				{ state.dropdown_title }
				<i class="fa fa-angle-down"></i>
			</a>
			<ul class="dropdown-menu dropdown-menu-right" aria-labelledby="dropdown{ state.control_id }">
				<li each="{ tab in state.dropdown }"><a href="#" class="{ state.tab == tab ? 'active' : '' }" onclick="{ tab_click }">{ tab.title }</a></li>
			</ul>
		</div>

		<div class="custom-tabs all-tabs" if="{ state.calculate }">
			<a href="#" each="{ tab in state.tabs }" class="tab">{ tab.title }</a>
		</div>
	</div>

	<div class="form-group" if="{ Device == 'sm' || Device == 'xs' }">
		<label if="{ state.label }">{ state.label }</label>
		<select class="form-control" onchange="{ tab_click }">
			<option value="" if="{ state.placeholder }">{ state.placeholder }</option>
			<option each="{ tab in state.tabs }" value="{ tab.id }" selected="{ state.tab == tab }">{ tab.title }</option>
		</select>
	</div>

	<script>
	/*
		Methods
		--------
		set_tabs ( array of tabs ) :: sets the tabs to display
		set_active_tab ( id of tab ) :: sets the active tab
		get_selected() :: returns the id of the selected tab
		get_selected_tab() :: returns the selected tab object

		Options:
		--------
		label :: sets the label to display on small and extra small devices
		placeholder :: sets the first select option to display on small and extra small devices
		unselect :: "true" = user can unselect the selected tab

		Events:
		-------
		onchangehandler( tab ) :: triggers when a tab is selected
	*/

		this.state = {
			control_id: "tabs-" + guidGenerator(), // create unique id for control
			label: this.opts.label,
			placeholder: this.opts.placeholder,
			unselect: this.opts.unselect == "true",

			dropdown_title: "ΑΛΛΟ",

			tab: null, // selected tab
			dropdown_tab: null, // selected tab from dropdown menu
			tabs: [],
			visible_tabs: [],
			dropdown: [],

			calculate: false,
			show_dropdown: false,
		}


		this.set_tabs = tabs => {
			this.state.tabs = tabs;
			// find preselected tab
			this.state.tab = this.state.tabs.find( x => x.selected == true ) || null;
			this.set_visible_tabs();
		}


		this.set_active_tab = id => {
			var tab = this.state.tabs.find( x => x.id == id);
			if (tab) {
				this.state.tab = tab;
				this.update();
			}
		}


		this.get_selected = () => {
			//return this.state.selected;
			return this.state.tab ? this.state.tab.id : "";
		}


		this.get_selected_tab = () => {
			return this.state.tab ? this.state.tab : null;
		}


		this.tab_click = event => {
			event.preventDefault();

			var tab = null;

			if (event.target.type == 'select-one') {
				// event is from "select" input
				tab = this.state.tabs.find( x => x.id == event.target.value);
				this.state.tab = tab;
			} else {
				// Event is from "tabs"
				tab = event.item.tab;

				if (this.state.unselect && this.state.tab == event.item.tab) {
					this.state.tab = null;
					this.state.dropdown_tab = null;
				} else {
					this.state.tab = tab;
				}

				if (this.in_dropdown_tabs(this.state.tab.id)) {
					// selected tab is from dropdown tabs
					this.state.dropdown_tab = tab;
				} else {
					this.state.dropdown_tab = null;
				}
				this.state.dropdown_title = this.state.dropdown_tab ? this.state.dropdown_tab.title : "ΑΛΛΟ";
				this.set_visible_tabs();
			}


			if (this.opts.onchangehandler) {
				this.opts.onchangehandler(tab);
			}
		}


		// Set the visible tabs and the dropdown menu tabs
		this.set_visible_tabs = () => {
			this.state.calculate = true;
			this.state.show_dropdown = true;
			this.update();

			this.state.visible_tabs = [];
			this.state.dropdown = [];
			var tag = this;

			var container_width = $("#" + this.state.control_id).width();
			//console.log("container_width: " + container_width);

			var all_tabs_width = $("#" + this.state.control_id + " .all-tabs").width();
			//console.log("all_tabs_width: " + all_tabs_width);

			var dropdown_width = $("#" + this.state.control_id + " .dropdown").outerWidth();
			//console.log("dropdown_width: " + dropdown_width);

			if (container_width >= all_tabs_width) {
				// if control container width is bigger than tabs width
				this.state.tabs.map( tab => {
					this.state.visible_tabs.push(tab);
				});
				this.state.show_dropdown = false;
			} else {
				// display only tabs that fit in control width
				var tabs_width = 0;

				$("#" + this.state.control_id + ' .all-tabs .tab').each(function(index, item) {

					var tab_width = $(item).outerWidth();

					if (tabs_width + tab_width + dropdown_width < container_width) {
						tag.state.visible_tabs.push(tag.state.tabs[index]);
					} else {
						tag.state.dropdown.push(tag.state.tabs[index]);
					}
					tabs_width+= tab_width;
				});
			}

			this.state.calculate = false;
			this.update();
		}


		this.in_visible_tabs = id => {
			return this.state.visible_tabs.find( x => x.id == id) || false;
		}
		this.in_dropdown_tabs = id => {
			return this.state.dropdown.find( x => x.id == id) || false;
		}

		this.on("mount", function() {
			var tag = this;
			$( window ).resize(function() {
		        tag.set_visible_tabs();
		    });
		});

	</script>
</control-tabs>